@@ -23,16 +23,13 @@ from django.conf import settings
 from horizon import exceptions
 import logging
 from openstack_dashboard.api import base
-import six
 
 from manilaclient import client as manila_client
 
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-# NOTE(vponomaryov): update version to 2.34 when manilaclient is released with
-# its support. It will allow to show 'availability zones' for share groups.
-MANILA_VERSION = "2.32"  # requires manilaclient 1.13.0 or newer
+MANILA_VERSION = "2.38"
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -47,6 +44,16 @@ MANILA_QUOTA_FIELDS = {
     "share_networks",
 }
 
+# UI field names do not match data field names returned, have
+# a map to convert them.
+MANILA_QUOTA_FIELDS_DATA_MAP = {
+    "shares": "shares",
+    "share_gigabytes": "gigabytes",
+    "share_snapshots": "snapshots",
+    "share_snapshot_gigabytes": "snapshot_gigabytes",
+    "share_networks": "share_networks"
+}
+
 
 def manilaclient(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
@@ -106,8 +113,8 @@ def share_delete(request, share_id, share_group_id=None):
 
 def share_update(request, share_id, name, description, is_public=''):
     share_data = {'display_name': name, 'display_description': description}
-    if not isinstance(is_public, six.string_types):
-        is_public = six.text_type(is_public)
+    if not isinstance(is_public, str):
+        is_public = str(is_public)
     if is_public and is_public.lower() != 'none':
         share_data['is_public'] = is_public
     return manilaclient(request).shares.update(share_id, **share_data)
@@ -387,11 +394,10 @@ def share_type_get(request, share_type_id):
 
 
 def share_type_create(request, name, spec_driver_handles_share_servers,
-                      spec_snapshot_support=True, is_public=True):
+                      is_public=True):
     return manilaclient(request).share_types.create(
         name=name,
         spec_driver_handles_share_servers=spec_driver_handles_share_servers,
-        spec_snapshot_support=spec_snapshot_support,
         is_public=is_public)
 
 
