@@ -12,17 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import NoReverseMatch  # noqa
-from django.core.urlresolvers import reverse
-from django.template.defaultfilters import title  # noqa
-from django.utils.translation import string_concat, ugettext_lazy  # noqa
+from django.template.defaultfilters import title
+from django.urls import reverse
+from django.utils.text import format_lazy
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 from horizon import exceptions
 from horizon import messages
 from horizon import tables
-from openstack_dashboard.usage import quotas
+from horizon.utils import filters
 
 from manila_ui.api import manila
 from manila_ui.dashboards.project.share_snapshots import tables as ss_tables
@@ -88,16 +87,24 @@ class CreateShare(tables.LinkAction):
     policy_rules = (("share", "share:create"),)
 
     def allowed(self, request, share=None):
-        usages = quotas.tenant_quota_usages(request)
-        if usages['shares']['available'] <= 0:
+        usages = manila.tenant_absolute_limits(request)
+        shares_allowed = (usages['maxTotalShares'] >
+                          usages['totalSharesUsed'] and
+                          usages['maxTotalShareGigabytes'] >
+                          usages['totalShareGigabytesUsed'])
+
+        if not shares_allowed:
             if "disabled" not in self.classes:
                 self.classes = [c for c in self.classes] + ['disabled']
-                self.verbose_name = string_concat(self.verbose_name, ' ',
-                                                  _("(Quota exceeded)"))
+                self.verbose_name = format_lazy(
+                    '{verbose_name} {quota_exceeded}',
+                    verbose_name=self.verbose_name,
+                    quota_exceeded=_("(Quota exceeded)"))
         else:
             self.verbose_name = _("Create Share")
             classes = [c for c in self.classes if c != "disabled"]
             self.classes = classes
+
         return True
 
 
@@ -167,7 +174,7 @@ class RevertShare(tables.LinkAction):
 
     def allowed(self, request, share=None):
         return (
-            share.revert_to_snapshot_support and
+            getattr(share, 'revert_to_snapshot_support', False) and
             share.status.lower() == "available"
         )
 
@@ -255,7 +262,8 @@ class SharesTableBase(tables.DataTable):
         return obj.name or obj.id
 
     def get_share_group_link(share):
-        if features.is_share_groups_enabled() and share.share_group_id:
+        if (features.is_share_groups_enabled() and
+                getattr(share, 'share_group_id', None)):
             return reverse(
                 "horizon:project:share_groups:detail",
                 args=(share.share_group_id,))
@@ -352,6 +360,10 @@ class RulesTable(tables.DataTable):
         "access_level", verbose_name=_("Access Level"))
     status = tables.Column("state", verbose_name=_("Status"))
     access_key = tables.Column("access_key", verbose_name=_("Access Key"))
+    created_at = tables.Column("created_at", verbose_name=_("Created At"),
+                               filters=(filters.parse_isotime,))
+    updated_at = tables.Column("updated_at", verbose_name=_("Updated At"),
+                               filters=(filters.parse_isotime,))
 
     def get_object_display(self, obj):
         return obj.id
