@@ -14,8 +14,8 @@
 
 import ddt
 from django.urls import reverse
-import mock
 from openstack_dashboard.api import neutron
+from unittest import mock
 
 from manila_ui.api import manila as api_manila
 from manila_ui.tests.dashboards.project import test_data
