@@ -14,12 +14,10 @@
 
 import ddt
 from django.core.handlers import wsgi
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from horizon import messages as horizon_messages
-import mock
 from openstack_dashboard.api import neutron
-from openstack_dashboard.usage import quotas
-import six
+from unittest import mock
 
 from manila_ui.api import manila as api_manila
 from manila_ui.dashboards.project.shares import forms
@@ -55,6 +53,9 @@ class ShareViewTests(test.APITestCase):
         self.mock_object(horizon_messages, "success")
         FAKE_ENVIRON = {'REQUEST_METHOD': 'GET', 'wsgi.input': 'fake_input'}
         self.request = wsgi.WSGIRequest(FAKE_ENVIRON)
+        self.mock_object(
+            api_manila, "tenant_absolute_limits",
+            mock.Mock(return_value=test_data.limits))
 
     def test_index(self):
         snaps = [test_data.snapshot, test_data.snapshot_mount_support]
@@ -69,14 +70,11 @@ class ShareViewTests(test.APITestCase):
         self.mock_object(
             api_manila, "share_network_list",
             mock.Mock(return_value=share_networks))
+        self.mock_object(
+            api_manila, "tenant_absolute_limits",
+            mock.Mock(return_value=test_data.limits))
         self.mock_object(
             neutron, "is_service_enabled", mock.Mock(return_value=[True]))
-        self.mock_object(
-            quotas, "tenant_limit_usages",
-            mock.Mock(return_value=test_data.quota_usage))
-        self.mock_object(
-            quotas, "tenant_quota_usages",
-            mock.Mock(return_value=test_data.quota_usage))
 
         res = self.client.get(INDEX_URL)
 
@@ -86,6 +84,7 @@ class ShareViewTests(test.APITestCase):
             mock.ANY, detailed=True)
         api_manila.share_list.assert_called_with(mock.ANY)
         api_manila.share_network_list.assert_called_with(mock.ANY)
+        api_manila.tenant_absolute_limits.assert_called_with(mock.ANY)
 
     @mock.patch.object(api_manila, 'availability_zone_list')
     def test_create_share(self, az_list):
@@ -290,7 +289,7 @@ class ShareViewTests(test.APITestCase):
         self.assertRedirectsNoFollow(res, INDEX_URL)
         api_manila.share_update.assert_called_once_with(
             mock.ANY, self.share, formData['name'], formData['description'],
-            is_public=six.text_type(formData['is_public']))
+            is_public=str(formData['is_public']))
         api_manila.share_get.assert_has_calls(
             [mock.call(mock.ANY, self.share.id) for i in (1, 2)])
 
@@ -357,13 +356,7 @@ class ShareViewTests(test.APITestCase):
 
     def test_extend_share_get(self):
         share = test_data.share
-        usage_limit = {
-            'maxTotalShareGigabytes': 250,
-            'totalShareGigabytesUsed': 20,
-        }
         url = reverse('horizon:project:shares:extend', args=[share.id])
-        self.mock_object(
-            quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
         self.mock_object(
             neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
@@ -375,14 +368,8 @@ class ShareViewTests(test.APITestCase):
 
     def test_extend_share_open_form_successfully(self):
         self.share.size = 5
-        usage_limit = {
-            'maxTotalShareGigabytes': self.share.size + 50,
-            'totalShareGigabytesUsed': self.share.size,
-        }
         url = reverse('horizon:project:shares:extend', args=[self.share.id])
         self.mock_object(api_manila, "share_extend")
-        self.mock_object(
-            quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
 
         response = self.client.get(url)
 
@@ -390,17 +377,11 @@ class ShareViewTests(test.APITestCase):
         self.assertTemplateUsed(response, 'project/shares/extend.html')
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         self.assertFalse(api_manila.share_extend.called)
-        quotas.tenant_limit_usages.assert_called_once_with(mock.ANY)
+        api_manila.tenant_absolute_limits.assert_called_once_with(mock.ANY)
 
     def test_extend_share_get_with_api_exception(self):
-        usage_limit = {
-            'maxTotalShareGigabytes': self.share.size + 50,
-            'totalShareGigabytesUsed': self.share.size,
-        }
         url = reverse('horizon:project:shares:extend', args=[self.share.id])
         self.mock_object(api_manila, "share_extend")
-        self.mock_object(
-            quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
         self.mock_object(
             api_manila, "share_get",
             mock.Mock(return_value=Exception('Fake share NotFound exception')))
@@ -412,7 +393,7 @@ class ShareViewTests(test.APITestCase):
             response, 'project/shares/shares/extend.html')
         self.assertFalse(api_manila.share_extend.called)
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
-        self.assertFalse(quotas.tenant_limit_usages.called)
+        self.assertFalse(api_manila.tenant_absolute_limits.called)
 
     @ddt.data(6, 54, 55)
     def test_extend_share_post_successfully(self, new_size):
@@ -421,11 +402,13 @@ class ShareViewTests(test.APITestCase):
         usage_limit = {
             'maxTotalShareGigabytes': self.share.size + 50,
             'totalShareGigabytesUsed': self.share.size,
+
         }
         url = reverse('horizon:project:shares:extend', args=[self.share.id])
         self.mock_object(api_manila, "share_extend")
         self.mock_object(
-            quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
+            api_manila, 'tenant_absolute_limits',
+            mock.Mock(return_value=usage_limit))
 
         response = self.client.post(url, form_data)
 
@@ -435,21 +418,22 @@ class ShareViewTests(test.APITestCase):
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         api_manila.share_extend.assert_called_once_with(
             mock.ANY, self.share.id, form_data['new_size'])
-        quotas.tenant_limit_usages.assert_called_once_with(mock.ANY)
+        api_manila.tenant_absolute_limits.assert_called_once_with(mock.ANY)
         self.assertRedirectsNoFollow(response, INDEX_URL)
 
     @ddt.data(0, 5, 56)
     def test_extend_share_post_with_invalid_value(self, new_size):
         self.share.size = 5
         form_data = {'new_size': new_size}
+        url = reverse('horizon:project:shares:extend', args=[self.share.id])
         usage_limit = {
             'maxTotalShareGigabytes': self.share.size + 50,
             'totalShareGigabytesUsed': self.share.size,
         }
-        url = reverse('horizon:project:shares:extend', args=[self.share.id])
         self.mock_object(api_manila, "share_extend")
         self.mock_object(
-            quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
+            api_manila, 'tenant_absolute_limits',
+            mock.Mock(return_value=usage_limit))
 
         response = self.client.post(url, form_data)
 
@@ -457,21 +441,15 @@ class ShareViewTests(test.APITestCase):
         self.assertTemplateUsed(response, 'project/shares/extend.html')
         self.assertFalse(api_manila.share_extend.called)
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
-        quotas.tenant_limit_usages.assert_called_with(mock.ANY)
+        api_manila.tenant_absolute_limits.assert_called_with(mock.ANY)
 
     def test_extend_share_post_with_api_exception(self):
         self.share.size = 5
         form_data = {'new_size': 30}
-        usage_limit = {
-            'maxTotalShareGigabytes': self.share.size + 50,
-            'totalShareGigabytesUsed': self.share.size,
-        }
         url = reverse('horizon:project:shares:extend', args=[self.share.id])
         self.mock_object(
             api_manila, "share_extend",
             mock.Mock(return_value=Exception('Fake API exception')))
-        self.mock_object(
-            quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
 
         response = self.client.post(url, form_data)
 
@@ -481,7 +459,7 @@ class ShareViewTests(test.APITestCase):
         api_manila.share_extend.assert_called_once_with(
             mock.ANY, self.share.id, form_data['new_size'])
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
-        quotas.tenant_limit_usages.assert_called_once_with(mock.ANY)
+        api_manila.tenant_absolute_limits.assert_called_once_with(mock.ANY)
         self.assertRedirectsNoFollow(response, INDEX_URL)
 
     def test_revert_to_snapshot_get_success(self):
@@ -657,34 +635,34 @@ class ShareViewTests(test.APITestCase):
             data.update({'is_public': is_public})
 
         with self.settings(OPENSTACK_MANILA_FEATURES={
-            'enable_public_shares': enable_public_shares}):
-                form = _get_form()
-                result = form.handle(self.request, data)
-                self.assertTrue(result)
-                self.assertEqual(
-                    enable_public_shares,
-                    form.enable_public_shares)
-                if enable_public_shares:
-                    self.assertIn("is_public", form.fields)
-                    self.assertTrue(form.fields["is_public"])
-                else:
-                    self.assertNotIn("is_public", form.fields)
-                api_manila.share_create.assert_called_once_with(
-                    self.request,
-                    availability_zone=data['availability_zone'],
-                    description=data['description'],
-                    is_public=is_public,
-                    metadata=utils.parse_str_meta(data['metadata'])[0],
-                    name=data['name'],
-                    proto=data['share_proto'],
-                    share_group_id=None,
-                    share_network=test_data.active_share_network.id,
-                    share_type=data['share_type'],
-                    size=data['size'],
-                    snapshot_id=data['snapshot_id'],
-                )
-                horizon_messages.success.assert_called_once_with(
-                    self.request, mock.ANY)
+                'enable_public_shares': enable_public_shares}):
+            form = _get_form()
+            result = form.handle(self.request, data)
+            self.assertTrue(result)
+            self.assertEqual(
+                enable_public_shares,
+                form.enable_public_shares)
+            if enable_public_shares:
+                self.assertIn("is_public", form.fields)
+                self.assertTrue(form.fields["is_public"])
+            else:
+                self.assertNotIn("is_public", form.fields)
+            api_manila.share_create.assert_called_once_with(
+                self.request,
+                availability_zone=data['availability_zone'],
+                description=data['description'],
+                is_public=is_public,
+                metadata=utils.parse_str_meta(data['metadata'])[0],
+                name=data['name'],
+                proto=data['share_proto'],
+                share_group_id=None,
+                share_network=test_data.active_share_network.id,
+                share_type=data['share_type'],
+                size=data['size'],
+                snapshot_id=data['snapshot_id'],
+            )
+            horizon_messages.success.assert_called_once_with(
+                self.request, mock.ANY)
 
     @ddt.data((True, True), (True, False), (False, False))
     @ddt.unpack
@@ -711,24 +689,24 @@ class ShareViewTests(test.APITestCase):
             data.update({'is_public': is_public})
 
         with self.settings(OPENSTACK_MANILA_FEATURES={
-            'enable_public_shares': enable_public_shares}):
-                form = _get_form(initial)
-                result = form.handle(self.request, data)
-                self.assertTrue(result)
-                self.assertEqual(
-                    enable_public_shares,
-                    form.enable_public_shares)
-                if enable_public_shares:
-                    self.assertIn("is_public", form.fields)
-                    self.assertTrue(form.fields["is_public"])
-                else:
-                    self.assertNotIn("is_public", form.fields)
-                api_manila.share_update.assert_called_once_with(
-                    self.request,
-                    self.share,
-                    data['name'],
-                    data['description'],
-                    is_public=is_public,
-                )
-                horizon_messages.success.assert_called_once_with(
-                    self.request, mock.ANY)
+                'enable_public_shares': enable_public_shares}):
+            form = _get_form(initial)
+            result = form.handle(self.request, data)
+            self.assertTrue(result)
+            self.assertEqual(
+                enable_public_shares,
+                form.enable_public_shares)
+            if enable_public_shares:
+                self.assertIn("is_public", form.fields)
+                self.assertTrue(form.fields["is_public"])
+            else:
+                self.assertNotIn("is_public", form.fields)
+            api_manila.share_update.assert_called_once_with(
+                self.request,
+                self.share,
+                data['name'],
+                data['description'],
+                is_public=is_public,
+            )
+            horizon_messages.success.assert_called_once_with(
+                self.request, mock.ANY)
