@@ -13,35 +13,19 @@
 #    under the License.
 import collections
 
-try:
-    # NOTE(vponomaryov): Try import latest modules, assuming we have
-    # manilaclient that is new enough and have v2 API support.
-    from manilaclient.v2 import quotas
-    from manilaclient.v2 import security_services
-    from manilaclient.v2 import share_networks
-    from manilaclient.v2 import share_snapshots
-    from manilaclient.v2 import share_types
-    from manilaclient.v2 import shares
-except ImportError:
-    # NOTE(vponomaryov): If we got here then we have old manilaclient.
-    from manilaclient.v1 import quotas
-    from manilaclient.v1 import security_services
-    from manilaclient.v1 import share_networks
-    from manilaclient.v1 import share_snapshots
-    from manilaclient.v1 import share_types
-    from manilaclient.v1 import shares
-
+from manilaclient.v2 import security_services
 from manilaclient.v2 import share_export_locations
 from manilaclient.v2 import share_group_snapshots
 from manilaclient.v2 import share_group_types
 from manilaclient.v2 import share_groups
 from manilaclient.v2 import share_instances
+from manilaclient.v2 import share_networks
 from manilaclient.v2 import share_replicas
 from manilaclient.v2 import share_servers
 from manilaclient.v2 import share_snapshot_export_locations
-
-from openstack_dashboard import api
-from openstack_dashboard.usage import quotas as usage_quotas
+from manilaclient.v2 import share_snapshots
+from manilaclient.v2 import share_types
+from manilaclient.v2 import shares
 
 
 class FakeAPIClient(object):
@@ -360,6 +344,17 @@ share_type_dhss_true = share_types.ShareType(
      'extra_specs': {'driver_handles_share_servers': True}}
 )
 
+share_type_alt = share_types.ShareType(
+    share_types.ShareTypeManager(FakeAPIClient),
+    {'id': 'share-type-id4',
+     'name': 'test-share-type4',
+     'share_type_access:is_public': True,
+     'extra_specs': {
+         'snapshot_support': True,
+         'driver_handles_share_servers': False}
+     }
+)
+
 share_group_type = share_group_types.ShareGroupType(
     share_group_types.ShareGroupTypeManager(FakeAPIClient),
     {'id': 'fake_share_group_type_id1',
@@ -387,6 +382,15 @@ share_group_type_dhss_true = share_group_types.ShareGroupType(
      'is_public': True}
 )
 
+share_group_type_alt = share_group_types.ShareGroupType(
+    share_group_types.ShareGroupTypeManager(FakeAPIClient),
+    {'id': 'fake_share_group_type_id4',
+     'name': 'fake_share_group_type_name',
+     'share_types': [share_type_alt.id],
+     'group_specs': {'k5': 'v5', 'k6': 'v6'},
+     'is_public': True}
+)
+
 share_group = share_groups.ShareGroup(
     share_groups.ShareGroupManager(FakeAPIClient),
     {'id': 'fake_share_group_id',
@@ -434,7 +438,7 @@ share_group_dhss_true = share_groups.ShareGroup(
      'share_server_id': 'fake_share_server_id',
      'availability_zone': None,
      'host': 'fake_host_987654321',
-     'consistent_snapshot_support': None,
+     'consistent_snapshot_support': 'pool',
      'created_at': '2017-05-31T23:59:59.000000',
      'project_id': 'fake_project_id_987654321'}
 )
@@ -466,24 +470,23 @@ share_group_snapshot_nameless = share_group_snapshots.ShareGroupSnapshot(
      'members': []}
 )
 
-# Quota Sets
-quota_data = dict(shares='1',
-                  share_snapshots='1',
-                  share_gigabytes='1000')
-quota = quotas.QuotaSet(quotas.QuotaSetManager(FakeAPIClient), quota_data)
-
-# Quota Usages
-quota_usage_data = {'gigabytes': {'used': 0, 'quota': 1000},
-                    'shares': {'used': 0, 'quota': 10},
-                    'snapshots': {'used': 0, 'quota': 10},
-                    'share_networks': {'used': 0, 'quota': 10}}
-quota_usage = usage_quotas.QuotaUsage()
-for k, v in quota_usage_data.items():
-    quota_usage.add_quota(api.base.Quota(k, v['quota']))
-    quota_usage.tally(k, v['used'])
-
 # Manila Limits
-limits = {"absolute": {"totalSharesUsed": 1,
-                       "totalShareGigabytesUsed": 5,
-                       "maxTotalShareGigabytes": 1000,
-                       "maxTotalShares": 10}}
+limits = {"totalSharesUsed": 1,
+          "totalShareSnapshotsUsed": 1,
+          "totalShareGigabytesUsed": 500,
+          "totalSnapshotGigabytesUsed": 500,
+          "maxTotalShares": 10,
+          "maxTotalShareSnapshots": 10,
+          "maxTotalShareGigabytes": 1000,
+          "maxTotalSnapshotGigabytes": 1000,
+          }
+
+limits_negative = {"totalSharesUsed": 10,
+                   "totalShareSnapshotsUsed": 10,
+                   "totalShareGigabytesUsed": 1000,
+                   "totalSnapshotGigabytesUsed": 1000,
+                   "maxTotalShares": 10,
+                   "maxTotalShareSnapshots": 10,
+                   "maxTotalShareGigabytes": 1000,
+                   "maxTotalSnapshotGigabytes": 1000,
+                   }
